Webgeodyn: visualisation tools for motions at the Earth's core surface

Streamfunctions at the CMB, superimposed with scalar fields
(e.g. radial magnetic field, flow norm... under several projections)
Earth's core surface (Aitoff projection)
Orthographic projection
Time-position maps of scalar fields (including geostrophic flow)
(with respect to longitude, latitude or curvilinear coordinates)
Cross-section of secular variation along Φ
Time series of surface core flow spherical harmonics coefficients
Time series of spherical harmonics coefficients
Comparison of core flow predictions observatories
(ground-based observatory series and virtual observatory series)
Comparison with observatories.
Mauersberger-Lowes spectra of the core quantities
for time-average, deviation or at a given date
Spectra of averaged core quantities